package com.ruoyi.ss.commandLog.mapper;

import java.util.List;
import com.ruoyi.ss.commandLog.domain.CommandLog;
import com.ruoyi.ss.commandLog.domain.CommandLogVO;
import com.ruoyi.ss.commandLog.domain.CommandLogQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 命令日志Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-13
 */
public interface CommandLogMapper
{
    /**
     * 查询命令日志
     *
     * @param id 命令日志主键
     * @return 命令日志
     */
    public CommandLogVO selectCommandLogById(Long id);

    /**
     * 查询命令日志列表
     *
     * @param query 命令日志
     * @return 命令日志集合
     */
    public List<CommandLogVO> selectCommandLogList(@Param("query")CommandLogQuery query);

    /**
     * 新增命令日志
     *
     * @param commandLog 命令日志
     * @return 结果
     */
    public int insertCommandLog(CommandLog commandLog);

    /**
     * 修改命令日志
     *
     * @param commandLog 命令日志
     * @return 结果
     */
    public int updateCommandLog(@Param("data") CommandLog commandLog);

    /**
     * 删除命令日志
     *
     * @param id 命令日志主键
     * @return 结果
     */
    public int deleteCommandLogById(Long id);

    /**
     * 批量删除命令日志
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCommandLogByIds(Long[] ids);
}
