package com.ruoyi.web.controller.ss;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.commandLog.domain.CommandLog;
import com.ruoyi.ss.commandLog.domain.CommandLogVO;
import com.ruoyi.ss.commandLog.domain.CommandLogQuery;
import com.ruoyi.ss.commandLog.service.ICommandLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 命令日志Controller
 *
 * @author ruoyi
 * @date 2024-12-13
 */
@RestController
@RequestMapping("/ss/commandLog")
public class CommandLogController extends BaseController
{
    @Autowired
    private ICommandLogService commandLogService;

    /**
     * 查询命令日志列表
     */
    @PreAuthorize("@ss.hasPermi('ss:commandLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(CommandLogQuery query)
    {
        startPage();
        startOrderBy();
        List<CommandLogVO> list = commandLogService.selectCommandLogList(query);
        return getDataTable(list);
    }

    /**
     * 导出命令日志列表
     */
    @PreAuthorize("@ss.hasPermi('ss:commandLog:export')")
    @Log(title = "命令日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CommandLogQuery query)
    {
        List<CommandLogVO> list = commandLogService.selectCommandLogList(query);
        ExcelUtil<CommandLogVO> util = new ExcelUtil<CommandLogVO>(CommandLogVO.class);
        util.exportExcel(response, list, "命令日志数据");
    }

    /**
     * 获取命令日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('ss:commandLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(commandLogService.selectCommandLogById(id));
    }

    /**
     * 新增命令日志
     */
    @PreAuthorize("@ss.hasPermi('ss:commandLog:add')")
    @Log(title = "命令日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CommandLog commandLog)
    {
        return toAjax(commandLogService.insertCommandLog(commandLog));
    }

    /**
     * 修改命令日志
     */
    @PreAuthorize("@ss.hasPermi('ss:commandLog:edit')")
    @Log(title = "命令日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CommandLog commandLog)
    {
        return toAjax(commandLogService.updateCommandLog(commandLog));
    }

    /**
     * 删除命令日志
     */
    @PreAuthorize("@ss.hasPermi('ss:commandLog:remove')")
    @Log(title = "命令日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(commandLogService.deleteCommandLogByIds(ids));
    }
}
